==> parser-2.3.0-beta.tgz: package/lib/esm/envelopes/dynamodb.js <==
import { DynamoDBStreamSchema } from '../schemas/index.js';
import { Envelope } from './envelope.js';
import { ParseError } from '../errors.js';
/**
 * DynamoDB Stream Envelope to extract data within NewImage/OldImage
 *
 * Note: Values are the parsed models. Images' values can also be None, and
 * length of the list is the record's amount in the original event.
 */
export class DynamoDBStreamEnvelope extends Envelope {
    static parse(data, schema) {
        const parsedEnvelope = DynamoDBStreamSchema.parse(data);
        return parsedEnvelope.Records.map((record) => {
            return {
                NewImage: super.parse(record.dynamodb.NewImage, schema),
                OldImage: super.parse(record.dynamodb.OldImage, schema),
            };
        });
    }
    static safeParse(data, schema) {
        const parsedEnvelope = DynamoDBStreamSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse DynamoDB Stream envelope', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedLogEvents = [];
        for (const record of parsedEnvelope.data.Records) {
            const parsedNewImage = super.safeParse(record.dynamodb.NewImage, schema);
            const parsedOldImage = super.safeParse(record.dynamodb.OldImage, schema);
            if (!parsedNewImage.success || !parsedOldImage.success) {
                return {
                    success: false,
                    error: !parsedNewImage.success
                        ? new ParseError('Failed to parse NewImage', parsedNewImage.error)
                        : new ParseError('Failed to parse OldImage', parsedOldImage.error),
                    originalEvent: data,
                };
            }
            else {
                parsedLogEvents.push({
                    NewImage: parsedNewImage.data,
                    OldImage: parsedOldImage.data,
                });
            }
        }
        return {
            success: true,
            data: parsedLogEvents,
        };
    }
}

==> parser-2.4.0-beta.tgz: package/lib/esm/envelopes/dynamodb.js <==
import { DynamoDBStreamSchema } from '../schemas/index.js';
import { Envelope } from './envelope.js';
import { ParseError } from '../errors.js';
/**
 * DynamoDB Stream Envelope to extract data within NewImage/OldImage
 *
 * Note: Values are the parsed models. Images' values can also be None, and
 * length of the list is the record's amount in the original event.
 */
export class DynamoDBStreamEnvelope extends Envelope {
    static parse(data, schema) {
        const parsedEnvelope = DynamoDBStreamSchema.parse(data);
        return parsedEnvelope.Records.map((record) => {
            return {
                NewImage: super.parse(record.dynamodb.NewImage, schema),
                OldImage: super.parse(record.dynamodb.OldImage, schema),
            };
        });
    }
    static safeParse(data, schema) {
        const parsedEnvelope = DynamoDBStreamSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new ParseError('Failed to parse DynamoDB Stream envelope', {
                    cause: parsedEnvelope.error,
                }),
                originalEvent: data,
            };
        }
        const parsedLogEvents = [];
        for (const record of parsedEnvelope.data.Records) {
            const parsedNewImage = super.safeParse(record.dynamodb.NewImage, schema);
            const parsedOldImage = super.safeParse(record.dynamodb.OldImage, schema);
            if (!parsedNewImage.success || !parsedOldImage.success) {
                return {
                    success: false,
                    error: !parsedNewImage.success
                        ? new ParseError('Failed to parse NewImage', {
                            cause: parsedNewImage.error,
                        })
                        : new ParseError('Failed to parse OldImage', {
                            cause: parsedOldImage.error,
                        }),
                    originalEvent: data,
                };
            }
            else {
                parsedLogEvents.push({
                    NewImage: parsedNewImage.data,
                    OldImage: parsedOldImage.data,
                });
            }
        }
        return {
            success: true,
            data: parsedLogEvents,
        };
    }
}
